==> owncloud-8.1.0p2.tgz: owncloud/core/l10n/he.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "יום ראשון",
    "Monday" : "יום שני",
    "Tuesday" : "יום שלישי",
    "Wednesday" : "יום רביעי",
    "Thursday" : "יום חמישי",
    "Friday" : "יום שישי",
    "Saturday" : "שבת",
    "January" : "ינואר",
    "February" : "פברואר",
    "March" : "מרץ",
    "April" : "אפריל",
    "May" : "מאי",
    "June" : "יוני",
    "July" : "יולי",
    "August" : "אוגוסט",
    "September" : "ספטמבר",
    "October" : "אוקטובר",
    "November" : "נובמבר",
    "December" : "דצמבר",
    "Settings" : "הגדרות",
    "Saving..." : "שמירה…",
    "No" : "לא",
    "Yes" : "כן",
    "Choose" : "בחירה",
    "Ok" : "בסדר",
    "New Files" : "קבצים חדשים",
    "Cancel" : "ביטול",
    "Shared" : "שותף",
    "Share" : "שתף",
    "Error" : "שגיאה",
    "Error while sharing" : "שגיאה במהלך השיתוף",
    "Error while unsharing" : "שגיאה במהלך ביטול השיתוף",
    "Error while changing permissions" : "שגיאה במהלך שינוי ההגדרות",
    "Shared with you and the group {group} by {owner}" : "שותף אתך ועם הקבוצה {group} שבבעלות {owner}",
    "Shared with you by {owner}" : "שותף אתך על ידי {owner}",
    "Share link" : "קישור לשיתוף",
    "Password protect" : "הגנה בססמה",
    "Password" : "סיסמא",
    "Email link to person" : "שליחת קישור בדוא״ל למשתמש",
    "Send" : "שליחה",
    "Set expiration date" : "הגדרת תאריך תפוגה",
    "Expiration date" : "תאריך התפוגה",
    "group" : "קבוצה",
    "Resharing is not allowed" : "אסור לעשות שיתוף מחדש",
    "Shared in {item} with {user}" : "שותף תחת {item} עם {user}",
    "Unshare" : "הסר שיתוף",
    "can share" : "ניתן לשתף",
    "can edit" : "ניתן לערוך",
    "access control" : "בקרת גישה",
    "create" : "יצירה",
    "delete" : "מחיקה",
    "Password protected" : "מוגן בססמה",
    "Error unsetting expiration date" : "אירעה שגיאה בביטול תאריך התפוגה",
    "Error setting expiration date" : "אירעה שגיאה בעת הגדרת תאריך התפוגה",
    "Sending ..." : "מתבצעת שליחה ...",
    "Email sent" : "הודעת הדוא״ל נשלחה",
    "Warning" : "אזהרה",
    "The object type is not specified." : "סוג הפריט לא צוין.",
    "Delete" : "מחיקה",
    "Add" : "הוספה",
    "The update was successful. Redirecting you to ownCloud now." : "תהליך העדכון הסתיים בהצלחה. עכשיו מנתב אותך אל ownCloud.",
    "Use the following link to reset your password: {link}" : "יש להשתמש בקישור הבא כדי לאפס את הססמה שלך: {link}",
    "New password" : "ססמה חדשה",
    "Reset password" : "איפוס ססמה",
    "Personal" : "אישי",
    "Users" : "משתמשים",
    "Apps" : "יישומים",
    "Admin" : "מנהל",
    "Help" : "עזרה",
    "Access forbidden" : "הגישה נחסמה",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "תיקיית וקבצי המידע שלך כנראה נגישים מהאינטרנט מכיוון שקובץ ה.htaccess לא עובד.",
    "Create an <strong>admin account</strong>" : "יצירת <strong>חשבון מנהל</strong>",
    "Username" : "שם משתמש",
    "Data folder" : "תיקיית נתונים",
    "Configure the database" : "הגדרת מסד הנתונים",
    "Database user" : "שם משתמש במסד הנתונים",
    "Database password" : "ססמת מסד הנתונים",
    "Database name" : "שם מסד הנתונים",
    "Database tablespace" : "מרחב הכתובות של מסד הנתונים",
    "Database host" : "שרת בסיס נתונים",
    "Finish setup" : "סיום התקנה",
    "Log out" : "התנתקות",
    "Search" : "חיפוש",
    "remember" : "שמירת הססמה",
    "Log in" : "כניסה",
    "Alternative Logins" : "כניסות אלטרנטיביות"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2p3.tgz: owncloud/core/l10n/he.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "יום ראשון",
    "Monday" : "יום שני",
    "Tuesday" : "יום שלישי",
    "Wednesday" : "יום רביעי",
    "Thursday" : "יום חמישי",
    "Friday" : "יום שישי",
    "Saturday" : "שבת",
    "Sun." : "ראשון",
    "Mon." : "שני",
    "Tue." : "שלישי",
    "Wed." : "רביעי",
    "Thu." : "חמישי",
    "Fri." : "שישי",
    "Sat." : "שבת",
    "January" : "ינואר",
    "February" : "פברואר",
    "March" : "מרץ",
    "April" : "אפריל",
    "May" : "מאי",
    "June" : "יוני",
    "July" : "יולי",
    "August" : "אוגוסט",
    "September" : "ספטמבר",
    "October" : "אוקטובר",
    "November" : "נובמבר",
    "December" : "דצמבר",
    "Jan." : "ינו׳",
    "Feb." : "פבר׳",
    "Mar." : "מרץ",
    "Apr." : "אפר׳",
    "May." : "מאי",
    "Jun." : "יונ׳",
    "Jul." : "יול׳",
    "Aug." : "אוג׳",
    "Sep." : "ספט׳",
    "Oct." : "אוק׳",
    "Nov." : "נוב׳",
    "Dec." : "דצמ׳",
    "Settings" : "הגדרות",
    "Saving..." : "שמירה…",
    "seconds ago" : "שניות",
    "No" : "לא",
    "Yes" : "כן",
    "Choose" : "בחירה",
    "Ok" : "בסדר",
    "New Files" : "קבצים חדשים",
    "Cancel" : "ביטול",
    "Shared" : "שותף",
    "Error" : "שגיאה",
    "Error while sharing" : "שגיאה במהלך השיתוף",
    "Error while unsharing" : "שגיאה במהלך ביטול השיתוף",
    "Error while changing permissions" : "שגיאה במהלך שינוי ההגדרות",
    "Error setting expiration date" : "אירעה שגיאה בעת הגדרת תאריך התפוגה",
    "Set expiration date" : "הגדרת תאריך תפוגה",
    "Expiration date" : "תאריך התפוגה",
    "Sending ..." : "מתבצעת שליחה ...",
    "Email sent" : "הודעת הדוא״ל נשלחה",
    "Resharing is not allowed" : "אסור לעשות שיתוף מחדש",
    "Share link" : "קישור לשיתוף",
    "Password protect" : "הגנה בססמה",
    "Password" : "סיסמא",
    "Email link to person" : "שליחת קישור בדוא״ל למשתמש",
    "Send" : "שליחה",
    "Shared with you and the group {group} by {owner}" : "שותף אתך ועם הקבוצה {group} שבבעלות {owner}",
    "Shared with you by {owner}" : "שותף אתך על ידי {owner}",
    "Shared in {item} with {user}" : "שותף תחת {item} עם {user}",
    "group" : "קבוצה",
    "Unshare" : "הסר שיתוף",
    "can share" : "ניתן לשתף",
    "can edit" : "ניתן לערוך",
    "create" : "יצירה",
    "delete" : "מחיקה",
    "access control" : "בקרת גישה",
    "Share" : "שתף",
    "Warning" : "אזהרה",
    "The object type is not specified." : "סוג הפריט לא צוין.",
    "Delete" : "מחיקה",
    "Add" : "הוספה",
    "The update was successful. Redirecting you to ownCloud now." : "תהליך העדכון הסתיים בהצלחה. עכשיו מנתב אותך אל ownCloud.",
    "Use the following link to reset your password: {link}" : "יש להשתמש בקישור הבא כדי לאפס את הססמה שלך: {link}",
    "New password" : "ססמה חדשה",
    "Reset password" : "איפוס ססמה",
    "Personal" : "אישי",
    "Users" : "משתמשים",
    "Apps" : "יישומים",
    "Admin" : "מנהל",
    "Help" : "עזרה",
    "Access forbidden" : "הגישה נחסמה",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "תיקיית וקבצי המידע שלך כנראה נגישים מהאינטרנט מכיוון שקובץ ה.htaccess לא עובד.",
    "Create an <strong>admin account</strong>" : "יצירת <strong>חשבון מנהל</strong>",
    "Username" : "שם משתמש",
    "Data folder" : "תיקיית נתונים",
    "Configure the database" : "הגדרת מסד הנתונים",
    "Database user" : "שם משתמש במסד הנתונים",
    "Database password" : "ססמת מסד הנתונים",
    "Database name" : "שם מסד הנתונים",
    "Database tablespace" : "מרחב הכתובות של מסד הנתונים",
    "Database host" : "שרת בסיס נתונים",
    "Finish setup" : "סיום התקנה",
    "Log out" : "התנתקות",
    "Search" : "חיפוש",
    "Log in" : "כניסה",
    "remember" : "שמירת הססמה",
    "Alternative Logins" : "כניסות אלטרנטיביות"
},
"nplurals=2; plural=(n != 1);");
